==> dl.php?src=linea21_2_0_0.zip: linea21/templates/public/2017/header.php <==
<?php
/**
 * @package linea21\core\public
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<head>
<!-- 
Lorsque supprimé, ne fonctionne pas si url rewriting activé
<base href="<?php echo CURRENT_APP_URL; ?>" />
 -->
<meta charset="<?php echo CHARSET; ?>" />
<!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge"><![endif]-->
<meta name="robots" content="index, follow" />
<meta name="description" content="" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, shrink-to-fit=no">
		<!--[if lt IE 9]>
		<script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
		<![endif]-->
<link rel="icon" type="image/gif" href="<?php echo PUBLIC_THEME_URL; ?>images/favicon.gif" />
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/knacss/css/knacss.css" media="all">
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/style.css" media="all" />
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/layout.css" media="all" />
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/vendor/font-awesome/css/font-awesome.min.css">
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/jquery-1.11.3.min.js"></script>
<script type="text/javascript" src="<?php echo SITE_ROOT_URL; ?>/lib/js/jquery-browser.js"></script>
<?php if(defined('AJAX_LOGIN') && AJAX_LOGIN == 1) echo '<script src="'.SITE_ROOT_URL.'lib/js/leanModal.v1.1/jquery.leanModal.min.js"></script>'; ?>
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/functions.js"></script>
<!--[if IE 8]>
		<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/ie8.css" media="screen" />
<![endif]-->
<link rel="alternate" title="RSS2" href="rss2.php" />
<?php distInclude(THEME_PUBLIC_PATH.'meta_data.php', THEME_PUBLIC_DIST); ?>
<?php
IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']"));
AddDynamicHeader();
?>
<title></title>
<?php if(isset($GLOBALS['debugbar'])) echo $GLOBALS['debugbarRenderer']->renderHead(); ?>
</head>

==> dl.php?src=linea21_2_3_0.zip: linea21/templates/public/2017/header.php <==
<?php
/**
 * @package linea21\core\public
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<head>
<meta charset="<?php echo CHARSET; ?>" />
<!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge"><![endif]-->
<meta name="robots" content="index, follow" />
<meta name="description" content="" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, shrink-to-fit=no">
		<!--[if lt IE 9]>
		<script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
		<![endif]-->
<link rel="icon" type="image/gif" href="<?php echo PUBLIC_THEME_URL; ?>images/favicon.gif" />
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/knacss/css/knacss.css" media="all">
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/style.css" media="all" />
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/layout.css" media="all" />
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/vendor/font-awesome/css/font-awesome.min.css">
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/jquery-1.11.3.min.js"></script>
<script type="text/javascript" src="<?php echo SITE_ROOT_URL; ?>/lib/js/jquery-browser.js"></script>
<?php if(defined('AJAX_LOGIN') && AJAX_LOGIN == 1) echo '<script src="'.SITE_ROOT_URL.'lib/js/leanModal.v1.1/jquery.leanModal.min.js"></script>'; ?>
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/functions.js"></script>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/print.css" media="print" />
<link rel="alternate" title="RSS2" href="rss2.php" />
<?php distInclude(THEME_PUBLIC_PATH.'meta_data.php', THEME_PUBLIC_DIST); ?>
<?php
IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']"));
AddDynamicHeader();
?>
<title></title>
<?php if(isset($GLOBALS['debugbar'])) echo $GLOBALS['debugbarRenderer']->renderHead(); ?>
</head>
